You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@allura.apache.org by he...@apache.org on 2016/01/19 21:04:40 UTC

allura git commit: Delete bootstrap tasks instead of running them; 30-40% speedup in test run time

Repository: allura
Updated Branches:
  refs/heads/master 375e1d10c -> 4787a804f


Delete bootstrap tasks instead of running them; 30-40% speedup in test run time


Project: http://git-wip-us.apache.org/repos/asf/allura/repo
Commit: http://git-wip-us.apache.org/repos/asf/allura/commit/4787a804
Tree: http://git-wip-us.apache.org/repos/asf/allura/tree/4787a804
Diff: http://git-wip-us.apache.org/repos/asf/allura/diff/4787a804

Branch: refs/heads/master
Commit: 4787a804f7db86b9c9b0d2891a299a92664ce507
Parents: 375e1d1
Author: Dave Brondsema <da...@brondsema.net>
Authored: Tue Jan 19 12:22:26 2016 -0500
Committer: Dave Brondsema <da...@brondsema.net>
Committed: Tue Jan 19 12:22:26 2016 -0500

----------------------------------------------------------------------
 AlluraTest/alluratest/controller.py | 5 ++---
 1 file changed, 2 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/allura/blob/4787a804/AlluraTest/alluratest/controller.py
----------------------------------------------------------------------
diff --git a/AlluraTest/alluratest/controller.py b/AlluraTest/alluratest/controller.py
index 6ce1b71..6b50f33 100644
--- a/AlluraTest/alluratest/controller.py
+++ b/AlluraTest/alluratest/controller.py
@@ -94,9 +94,8 @@ def setup_basic_test(config=None, app_name=DFL_APP_NAME):
     cmd.run([test_file])
     ew.TemplateEngine.initialize({})
 
-    # run all tasks, e.g. indexing from bootstrap operations
-    while M.MonQTask.run_ready('setup'):
-        ThreadLocalORMSession.flush_all()
+    # remove unnecessary bootstrap tasks, e.g. search indexing
+    M.MonQTask.query.remove({'state': 'ready'})
 setup_basic_test.__test__ = False  # sometimes __test__ above isn't sufficient